@@ -1,7 +1,7 @@
-/* pg_hint_plan/pg_hint_plan--1.5--1.5.1.sql */
+/* pg_hint_plan/pg_hint_plan--1.5.1--1.5.2.sql */
 
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
-\echo Use "ALTER EXTENSION pg_dbms_stats UPDATE TO '1.5.1'" to load this file. \quit
+\echo Use "ALTER EXTENSION pg_hint_plan UPDATE TO '1.5.2'" to load this file. \quit
 
 SELECT pg_catalog.pg_extension_config_dump('hint_plan.hints','');
 SELECT pg_catalog.pg_extension_config_dump('hint_plan.hints_id_seq','');
